pub struct RedactedString(/* private fields */);Expand description
String wrapper that refuses to render its value in Debug or
Display. The value is only accessible via Self::expose — by
convention, callers should not log the result of expose().
Implementations